[Asterisk-cvs] asterisk/cdr cdr_odbc.c,1.29,1.30

russell at lists.digium.com russell at lists.digium.com
Thu Jul 14 16:00:40 CDT 2005


Update of /usr/cvsroot/asterisk/cdr
In directory mongoose.digium.com:/tmp/cvs-serv4617/cdr

Modified Files:
	cdr_odbc.c 
Log Message:
clarify comment


Index: cdr_odbc.c
===================================================================
RCS file: /usr/cvsroot/asterisk/cdr/cdr_odbc.c,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -d -r1.29 -r1.30
--- cdr_odbc.c	11 Jul 2005 21:06:27 -0000	1.29
+++ cdr_odbc.c	14 Jul 2005 20:08:31 -0000	1.30
@@ -406,7 +406,8 @@
 		SQLSetConnectAttr(ODBC_con, SQL_LOGIN_TIMEOUT, (SQLPOINTER *)10, 0);	
 	}
 
-	/* XXX note username and password could be NULL here */
+	/* Note that the username and password could be NULL here, but that is allowed in ODBC.
+           In this case, the default username and password will be used from odbc.conf */
 	ODBC_res = SQLConnect(ODBC_con, (SQLCHAR*)dsn, SQL_NTS, (SQLCHAR*)username, SQL_NTS, (SQLCHAR*)password, SQL_NTS);
 
 	if ((ODBC_res != SQL_SUCCESS) && (ODBC_res != SQL_SUCCESS_WITH_INFO)) {




More information about the svn-commits mailing list